#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.schema import Bool

from pyams_content import _
from pyams_i18n.schema import I18nTextLineField
from pyams_portal.interfaces import IPortletSettings


class ISharedContentHeaderPortletSettings(IPortletSettings):
    """Shared content header portlet settings"""

    display_breadcrumbs = Bool(title=_("Display breadcrumbs?"),
                               required=True,
                               default=True)

    display_title = Bool(title=_("Display title?"),
                         required=True,
                         default=True)

    display_tags = Bool(title=_("Display tags?"),
                        required=True,
                        default=True)

    display_header = Bool(title=_("Display header?"),
                          required=True,
                          default=True)

    display_publication_date = Bool(title=_("Display publication date?"),
                                    description=_("If 'yes', content publication date will be "
                                                  "displayed; the selected publication date is "
                                                  "those which is selected while publishing the "
                                                  "content"),
                                    required=True,
                                    default=False)

    publication_date_prefix = I18nTextLineField(title=_("Publication date prefix"),
                                                description=_("This text will be displayed "
                                                              "before publication date"),
                                                required=False)

    display_specificities = Bool(title=_("Display specificities?"),
                                 description=_("If 'no', specific content's informations won't "
                                               "be displayed..."),
                                 required=True,
                                 default=True)


class ISharedContentTitlePortletSettings(IPortletSettings):
    """Shared content title portlet settings"""

    display_publication_date = Bool(title=_("Display publication date?"),
                                    description=_("If 'yes', content publication date will be "
                                                  "displayed; the selected publication date is "
                                                  "those which is selected while publishing the "
                                                  "content"),
                                    required=True,
                                    default=False)

    publication_date_prefix = I18nTextLineField(title=_("Publication date prefix"),
                                                description=_("This text will be displayed "
                                                              "before publication date"),
                                                required=False)


class ISharedContentSpecificitiesPortletSettings(IPortletSettings):
    """Shared content specificities portlet settings"""
